==> mythplugins_0.18.1.orig.tar.gz: mythplugins-0.18.1/mythgallery/i18n/mythgallery_si.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation>Mapa:</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Ustvarjena:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Spremenjena:</translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bajti</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Širina</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>piksli</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Višina</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Število pikslov</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapiksli</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Kot zasuka</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>stopinje</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>Oprostite: OpenGL podpora ni na voljo</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Prezentacija</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>Zasuk CW</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>Zasuk CCW</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Uvozi</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Import pictures?</source>
        <translation>Uvoz slik?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Za uvoz nisem najdel nič</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Vredu</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Mapa s slikami</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Ta mapa mora obstajati in uporabnik mora imeti bralne pravice.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Pot za uvoz slik</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Z dvopičjem ločen seznam poti. Če je pot na seznamu mapa, se bo kopirala njena vsebina. Če je datoteka zagonska, se bo zagnala.</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Uporabi OpenGL prehode</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Označi za omogočitev OpenGL baziranih prezentacijskih prehodov</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Tip OpenGL prehoda</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Tip OpenGL prehoda uporabljenega med slikami in prezentacijo.</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Tip prehoda</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Tip prehoda uporabljenega med slikami in prezentacijo.</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Tip ozadja</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Tip ozadja za vsako sliko v načinu enojni pogled.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Zakasnitev prezentacije</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Število sekund za prikaz vsake slike.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation>MythGallery nastavitve</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation>Mapa z slikami ne obstaja ali pa ni bralna.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Vredu</translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Folder: </source>
        <translation>Mapa:</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation>Ustvarjena:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation>Spremenjena:</translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation>Bajti</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Širina</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation>piksli</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Višina</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation>Število pikslov</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation>megapiksli</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation>Kot zasuka</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation>stopinje</translation>
    </message>
</context>
</TS>

==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythgallery/i18n/mythgallery_si.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>GLSingleView</name>
    <message>
        <source>Folder: </source>
        <translation type="obsolete">Mapa:</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="obsolete">Ustvarjena:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="obsolete">Spremenjena:</translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation type="obsolete">Bajti</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="obsolete">Širina</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="obsolete">piksli</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="obsolete">Višina</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="obsolete">Število pikslov</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="obsolete">megapiksli</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="obsolete">Kot zasuka</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="obsolete">stopinje</translation>
    </message>
</context>
<context>
    <name>IconView</name>
    <message>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <source>Sorry: OpenGL support not available</source>
        <translation>Oprostite: OpenGL podpora ni na voljo</translation>
    </message>
    <message>
        <source>SlideShow</source>
        <translation>Prezentacija</translation>
    </message>
    <message>
        <source>Rotate CW</source>
        <translation>Zasuk CW</translation>
    </message>
    <message>
        <source>Rotate CCW</source>
        <translation>Zasuk CCW</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Uvozi</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavitve</translation>
    </message>
    <message>
        <source>Import pictures?</source>
        <translation>Uvoz slik?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Ne</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Da</translation>
    </message>
    <message>
        <source>Nothing found to import</source>
        <translation>Za uvoz nisem najdel nič</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Vredu</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Naključno</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Directory &apos;%1&apos; does not exist or is unreadable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery failed to load theme, see console for details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The selected device is no longer available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta Data...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marking...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Marked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Dir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Current File or Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting 1 folder, including any subfolders and files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting 1 image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Marked Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Deleting %1 images and folders, including any subfolders and files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Moving marked images...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copying marked images...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds images</source>
        <translation>Mapa s slikami</translation>
    </message>
    <message>
        <source>This directory must exist and MythGallery needs to have read permission.</source>
        <translation>Ta mapa mora obstajati in uporabnik mora imeti bralne pravice.</translation>
    </message>
    <message>
        <source>Paths to import images from</source>
        <translation>Pot za uvoz slik</translation>
    </message>
    <message>
        <source>This is a colon separated list of paths. If the path in the list is a directory, its contents will be copied. If it is an executable, it will be run.</source>
        <translation>Z dvopičjem ločen seznam poti. Če je pot na seznamu mapa, se bo kopirala njena vsebina. Če je datoteka zagonska, se bo zagnala.</translation>
    </message>
    <message>
        <source>Use OpenGL transitions</source>
        <translation>Uporabi OpenGL prehode</translation>
    </message>
    <message>
        <source>Check this to enable OpenGL based slideshow transitions</source>
        <translation>Označi za omogočitev OpenGL baziranih prezentacijskih prehodov</translation>
    </message>
    <message>
        <source>Type of OpenGL transition</source>
        <translation>Tip OpenGL prehoda</translation>
    </message>
    <message>
        <source>This is the type of OpenGL transition used between pictures in slideshow mode.</source>
        <translation>Tip OpenGL prehoda uporabljenega med slikami in prezentacijo.</translation>
    </message>
    <message>
        <source>Type of transition</source>
        <translation>Tip prehoda</translation>
    </message>
    <message>
        <source>This is the type of transition used between pictures in slideshow mode.</source>
        <translation>Tip prehoda uporabljenega med slikami in prezentacijo.</translation>
    </message>
    <message>
        <source>Type of background</source>
        <translation>Tip ozadja</translation>
    </message>
    <message>
        <source>This is the type of background for each picture in single view mode.</source>
        <translation>Tip ozadja za vsako sliko v načinu enojni pogled.</translation>
    </message>
    <message>
        <source>Slideshow Delay</source>
        <translation>Zakasnitev prezentacije</translation>
    </message>
    <message>
        <source>This is the number of seconds to display each picture.</source>
        <translation>Število sekund za prikaz vsake slike.</translation>
    </message>
    <message>
        <source>MythGallery Settings</source>
        <translation type="obsolete">MythGallery nastavitve</translation>
    </message>
    <message>
        <source>Gallery Directory does not exist or is unreadable.</source>
        <translation type="obsolete">Mapa z slikami ne obstaja ali pa ni bralna.</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Vredu</translation>
    </message>
    <message>
        <source>Command run to display movie files</source>
        <translation>Ukaz za prikaz filmov</translation>
    </message>
    <message>
        <source>This command is executed whenever a movie file is selected</source>
        <translation>Ta ukaz se bo izvedel ob izboru filma</translation>
    </message>
    <message>
        <source>Store thumbnails in image directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, thumbnails are stored in &apos;.thumbcache&apos; directories within the above directory. If cleared, they are stored in your home directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recurse into directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check this to let the slideshow recurse into sub-directories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overlay caption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the number of seconds to show a caption on top of a full size picture.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort order when browsing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the sort order for the displayed picture thumbnails.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duration of OpenGL Transition (milliseconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Settings (Slideshow)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MythGallery Settings (General)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SingleView</name>
    <message>
        <source>Folder: </source>
        <translation type="obsolete">Mapa:</translation>
    </message>
    <message>
        <source>Created: </source>
        <translation type="obsolete">Ustvarjena:</translation>
    </message>
    <message>
        <source>Modified: </source>
        <translation type="obsolete">Spremenjena:</translation>
    </message>
    <message>
        <source>Bytes</source>
        <translation type="obsolete">Bajti</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="obsolete">Širina</translation>
    </message>
    <message>
        <source>pixels</source>
        <translation type="obsolete">piksli</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="obsolete">Višina</translation>
    </message>
    <message>
        <source>Pixel Count</source>
        <translation type="obsolete">Število pikslov</translation>
    </message>
    <message>
        <source>megapixels</source>
        <translation type="obsolete">megapiksli</translation>
    </message>
    <message>
        <source>Rotation Angle</source>
        <translation type="obsolete">Kot zasuka</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="obsolete">stopinje</translation>
    </message>
</context>
</TS>
